/* Copyright (c) 2013 APDM.
*
* utils.js
*
* Utility functions used across different scripts.
*/

var utils = function() {
    utils = {};

    // Utility to allow parsing of host and port from url
    var getLocation = function(href) {
        var url = document.createElement("a");
        url.href = href;
        return url;
    };

    // Return the "filepath" parameter passed with the URL. We can be a
    // little lazy here since we know this will be the only param passed.
    utils.parseURLParams = function (url) {
        // Find the server host and port
        var serverHost = getLocation(url).hostname;
        var serverPort = getLocation(url).port;

        var dataPath = null;
        var eventsPath = null;
        var start = url.indexOf("?") + 1;
        var end = url.length + 1;
        var param = url.slice(start, end - 1);

        if (param !== url && param !== "") {
            var values = param.split("&");
            for (var i = 0; i < values.length; i++) {
                var nameValue = values[i].split("=");
                if (nameValue[0] === "dataFile") {
                    dataPath = decodeURIComponent(nameValue[1]);
                } else if (nameValue[0] === "eventsFile") {
                    eventsPath = decodeURIComponent(nameValue[1]);
                }
            }
        }

        return { serverHost: serverHost, serverPort: serverPort,
                 dataFile: dataPath, eventsFile: eventsPath };
    };

    // Determine elapsed time given a time difference in microseconds
    utils.getTimeRange = function (timeDiff) {
        timeDiff = timeDiff / 1000;
        var seconds = Math.round(timeDiff % 60);
        timeDiff = timeDiff / Math.round(60);
        var minutes = Math.round(timeDiff % 60);
        timeDiff = timeDiff / Math.round(60);
        var hours = Math.round(timeDiff % 24);
        return { secondsElapased: seconds, minutesElapased: minutes,
                 hoursElapased: hours };
    };

    /**
     * Return a formatted date string, given the date string that
     * MobilityLab generates.
     * @param dateStr Date string formated as %Y%m%d-%H%M%S
     * @return Date as string of format %b %e, %Y - %H:%M:%S
     */
    utils.getFormattedDate = function(dateStr) {
        var format = d3.time.format("%b %e, %Y - %H:%M:%S");
        return format(utils.getDateFromString(dateStr));
    };

    /**
     * Return a short formatted date string, given the date string that
     * MobilityLab generates.
     * @param dateStr Date string formated as %Y%m%d-%H%M%S
     * @return Date as string of format %Y-%m-%d %H:%M
     */
    utils.getShortFormattedDate = function(dateStr) {
        var format = d3.time.format("%Y-%m-%d %H:%M");
        return format(utils.getDateFromString(dateStr));
    };

    utils.getDateFromString = function(dateStr) {
        var format = d3.time.format("%Y%m%d-%H%M%S");
        var date = format.parse(dateStr);
        return date;
    };

    utils.getStringFromDate = function(date) {
        var format = d3.time.format("%b %e, %Y - %H:%M:%S");
        return format(date);
    };

    utils.percentChange = function(newValue, oldValue) {
        if (oldValue === 0) return null;

        return ((newValue - oldValue) / oldValue) * 100;
    };

    return utils;
}();
